#!/usr/bin/perl
########################################################################
#
# $Id: msg_clean.pl,v 1.30 2020/06/17 20:03:32 gosha Exp $
#
#		(c) Okunev Igor <igor[at]prv.mts-nn.ru>
#						2008 - 2019 
#
########################################################################
package VirtualPBX;

open STDERR, '>>/var/log/VirtualPBX/XVB.stderr';

use strict;

use lib qw( /opt/VirtualPBX/lib );

use XVB::Core;
use XVB::Database;
use XVB::Mailboxes;
use XVB::Messages;
use XVB::UI::AGI::Messages;
use XVB::Admin;
use XVB::Journal;
use XVB::MC;
						
########################################################################
							main();
########################################################################


########################################################################
#
sub new {
	my ( $class, $config_file ) = @_;

	my $obj = bless { 	_CONF	=> {}, 
						_CDR	=> {
							CALLED_ID => 'cleaner',
							CALLER_ID => 'cleaner'
						},
						_DB => { PERSISTENT_CONNECTION => 1 } }, $class;

	$obj->core_cfg_init( $config_file );

	$obj->core_log_init();

	return $obj;
}

########################################################################
#
sub main {
	my $obj = new VirtualPBX( '/opt/VirtualPBX/etc/xvb.cfg' );

	my $sql = 'select
					a.ACCESS_CODE,
					f.*
				from
					' . $obj->core_cfg_get( 'TABLES_VBOXES_RECORD_FILES' ) . ' f,
					' . $obj->core_cfg_get( 'TABLES_ACCOUNT' ) . ' a, 
					' . $obj->core_cfg_get( 'TABLES_VBOX_CORE' ) . ' v
				where
					v.SUBSCR_ID = a.ID and
					v.ID = f.ID and 
					f.FILE_TYPE < 8
				order by
					a.ACCESS_CODE, f.ID';

	my $files = $obj->db_get_array_hashref( $sql );

	return unless $files;

	my $counter = 0;
	
	my $media_dir = $obj->core_cfg_get( 'PATH_USER_MEDIA_DIR' );
	my $media_dir_old = $obj->core_cfg_get( 'PATH_MEDIA_DIR' );

	my ( $cur_ac, $cur_id );

	foreach my $ref ( @{ $files } ) {
		my $file_path =  $media_dir .'/'. sprintf( '%3.3d', substr($ref->{'ACCESS_CODE'},-3) ) .'/'. $ref->{'ACCESS_CODE'};
		my $file_path_old =  $media_dir_old .'/'. sprintf( '%3.3d', substr($ref->{'ACCESS_CODE'},-3) ) .'/'. $ref->{'ACCESS_CODE'};
		
		next if $file_path_old eq $file_path;
	
		my $vb_id = $obj->core_vboxes()->{$ext_id}->{'ID'};

		if ( $ref->{'ACCESS_CODE'} ne $cur_ac ) {
			$obj->core_run_system( "mkdir -p $file_path" ) unless -e $file_path;
			$cur_ac = $ref->{'ACCESS_CODE'};
		}

		my $ext_file_path = $file_path .'/'. $ref->{'ID'};
		my $ext_file_path_old = $file_path_old .'/'. $ref->{'ID'};

		if ( $ref->{'ID'} ne $cur_id ) {
			$obj->core_run_system( "mkdir -p $ext_file_path" ) unless -e $ext_file_path;
			$cur_id = $ref->{'ID'};
		}
		
		$obj->core_run_system( "mv $ext_file_path_old/". $ref->{'FILE_NAME'} ." $ext_file_path/1-". $ref->{'FILE_NAME'});
		
		my $txt_name = $ref->{'FILE_NAME'};
		$txt_name =~ s/\.([^\w\d]+)$/.txt/;
		my $ast_ext = $1;
		$obj->core_run_system( "mv $ext_file_path_old/$txt_name $ext_file_path/1-$txt_name");

		if ( $ref->{'FILE_TYPE'} == 5 ) {
			# MOH
			$obj->core_run_system( "mkdir -p $file_path/.moh" );
 			$obj->core_run_system( "ln -s $ext_file_path/1-". $ref->{'FILE_NAME'} ." $file_path/.moh/moh.$ast_ext" );
		}
	}
	
	$sql = 'update 
					' . $obj->core_cfg_get( 'TABLES_VBOXES_RECORD_FILES' ) . '
				set 
					FILE_NAME = concat("1-",FILE_NAME)
				where
					f.FILE_TYPE < 8';
	
	#
	# MOH отдельно для всех юзерей таблицу обновлять и создавать дирректорию
	#
	$sql = 'update 
					' . $obj->core_cfg_get( 'TABLES_VBOXES_RECORD_FILES' ) . '
				set 
					FILE_NAME = concat("1-",FILE_NAME)
				where
					f.FILE_TYPE < 8';
}
